==> haskell-hsyaml-0.1.1.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsYAML
version: 0.1.1.2
id: HsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
key: HsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
license: GPL-2.0-only
copyright: 2015-2018 Herbert Valerio Riedel
           , 2007-2008 Oren Ben-Kiki
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/HsYAML
synopsis: Pure Haskell YAML 1.2 parser
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) parser implementation for Haskell.
    .
    Features of @HsYAML@ include:
    .
    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas).
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").
    .
category: Text
abi: c5b68df9aae1c6fed8b6d44ce2386dd1
exposed: True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Token
hidden-modules: Data.YAML.Loader Data.YAML.Schema
                Data.YAML.Token.Encoding Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/HsYAML-0.1.1.2
hs-libraries: HSHsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD containers-0.5.11.0
    text-1.2.3.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
haddock-interfaces: /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html: /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-0.1.1.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsYAML
version: 0.1.1.2
id: HsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
key: HsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
license: GPL-2.0-only
copyright: 2015-2018 Herbert Valerio Riedel
           , 2007-2008 Oren Ben-Kiki
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/HsYAML
synopsis: Pure Haskell YAML 1.2 parser
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) parser implementation for Haskell.
    .
    Features of @HsYAML@ include:
    .
    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas).
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").
    .
category: Text
abi: 951f685739b4fd0d8add656a85c94a17
exposed: True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Token
hidden-modules: Data.YAML.Loader Data.YAML.Schema
                Data.YAML.Token.Encoding Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/HsYAML-0.1.1.2
hs-libraries: HSHsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6 containers-0.5.11.0
    text-1.2.3.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=a89500558697401c3bf5eb58146baa5c
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
haddock-interfaces: /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html: /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
